import { DesignType } from './DesignType';
export declare class QRData {
    readonly type: DesignType;
    readonly index?: number;
    private readonly data;
    constructor(type: DesignType, index?: number);
    static fromBytes(data: Uint8Array, index?: number): QRData;
    /**
     * The design's title (UTF-16 encoded, up to 42 bytes).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get title(): string | undefined;
    set title(value: string | undefined);
    /**
     * The player ID (2 bytes).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get playerId(): number | undefined;
    set playerId(value: number | undefined);
    /**
     * The creator's name (UTF-16 encoded, up to 18 bytes).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get creator(): string | undefined;
    set creator(value: string | undefined);
    /**
     * The creator's sex (1 byte).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get sex(): number | undefined;
    set sex(value: number | undefined);
    /**
     * The village ID (2 bytes).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get villageId(): number | undefined;
    set villageId(value: number | undefined);
    /**
     * The village name (UTF-16 encoded, up to 18 bytes).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get village(): string | undefined;
    set village(value: string | undefined);
    /**
     * The language ID (1 byte).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get language(): number | undefined;
    set language(value: number | undefined);
    /**
     * The country ID (1 byte).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get country(): number | undefined;
    set country(value: number | undefined);
    /**
     * The region ID (1 byte).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get region(): number | undefined;
    set region(value: number | undefined);
    /**
     * The palette colors (15 bytes).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get paletteColors(): Uint8Array | undefined;
    set paletteColors(value: Uint8Array | undefined);
    /**
     * The color (this field's purpose is currently unknown) (1 byte).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get color(): number | undefined;
    set color(value: number | undefined);
    /**
     * The looks (this field's purpose is currently unknown) (1 byte).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get looks(): number | undefined;
    set looks(value: number | undefined);
    /**
     * The usage (1 byte).
     * Only supported for normal design QR codes and the first QR code for pro designs.
     */
    get usage(): number | undefined;
    set usage(value: number | undefined);
    /**
     * Each pixel's color data.
     * For pro designs, this only contains a segment of the full design's pixel data.
     * Total size varies depending on QR code type and index.
     */
    get colorData(): Uint8Array;
    set colorData(value: Uint8Array);
    private colorDataByteRange;
    loadBytes(data: Uint8Array): this;
    getBytes(): Uint8Array;
    private hasMetadata;
    private throwIfInvalidMetadataSetter;
    private getNewBuffer;
    private getByteSubset;
    private getString;
    private getNumber;
    private setByteSubset;
    private setString;
    private setNumber;
}
